# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from empire_platform_api_public_client.models.platform_appearance import PlatformAppearance
from empire_platform_api_public_client.models.user_preferences_general_notifications import UserPreferencesGeneralNotifications
from empire_platform_api_public_client.models.user_preferences_subscription_notifications import UserPreferencesSubscriptionNotifications

class UserPreferences(BaseModel):
    """
    UserPreferences
    """
    general_notifications: UserPreferencesGeneralNotifications = Field(..., alias="generalNotifications")
    subscription_notifications: UserPreferencesSubscriptionNotifications = Field(..., alias="subscriptionNotifications")
    appearance: PlatformAppearance = Field(...)
    __properties = ["generalNotifications", "subscriptionNotifications", "appearance"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UserPreferences:
        """Create an instance of UserPreferences from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of general_notifications
        if self.general_notifications:
            _dict['generalNotifications'] = self.general_notifications.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscription_notifications
        if self.subscription_notifications:
            _dict['subscriptionNotifications'] = self.subscription_notifications.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UserPreferences:
        """Create an instance of UserPreferences from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UserPreferences.parse_obj(obj)

        _obj = UserPreferences.parse_obj({
            "general_notifications": UserPreferencesGeneralNotifications.from_dict(obj.get("generalNotifications")) if obj.get("generalNotifications") is not None else None,
            "subscription_notifications": UserPreferencesSubscriptionNotifications.from_dict(obj.get("subscriptionNotifications")) if obj.get("subscriptionNotifications") is not None else None,
            "appearance": obj.get("appearance")
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.secondary_market_noticeboard_entry_batch import SecondaryMarketNoticeboardEntryBatch  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestSecondaryMarketNoticeboardEntryBatch(unittest.TestCase):
    """SecondaryMarketNoticeboardEntryBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecondaryMarketNoticeboardEntryBatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketNoticeboardEntryBatch`
        """
        model = empire_platform_api_public_client.models.secondary_market_noticeboard_entry_batch.SecondaryMarketNoticeboardEntryBatch()  # noqa: E501
        if include_optional :
            return SecondaryMarketNoticeboardEntryBatch(
                entries = [
                    empire_platform_api_public_client.models.secondary_market_noticeboard_entry.SecondaryMarketNoticeboardEntry(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        type = 'BUY', 
                        delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                            start = 'Tue Jan 04 00:00:00 UTC 2022', 
                            end = 'Tue Jan 04 00:00:00 UTC 2022', ), 
                        timescale = 'LONG_TERM', 
                        direction = 'GB_NL', 
                        notice_capacity = 56, 
                        notice_price = 1.337, 
                        posted_at = '2022-01-04T00:00Z', 
                        status = 'ACTIVE', 
                        expires_at = '2022-01-04T00:00Z', 
                        is_own = True, )
                    ], 
                total_count = 0
            )
        else :
            return SecondaryMarketNoticeboardEntryBatch(
                entries = [
                    empire_platform_api_public_client.models.secondary_market_noticeboard_entry.SecondaryMarketNoticeboardEntry(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        type = 'BUY', 
                        delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                            start = 'Tue Jan 04 00:00:00 UTC 2022', 
                            end = 'Tue Jan 04 00:00:00 UTC 2022', ), 
                        timescale = 'LONG_TERM', 
                        direction = 'GB_NL', 
                        notice_capacity = 56, 
                        notice_price = 1.337, 
                        posted_at = '2022-01-04T00:00Z', 
                        status = 'ACTIVE', 
                        expires_at = '2022-01-04T00:00Z', 
                        is_own = True, )
                    ],
                total_count = 0,
        )
        """

    def testSecondaryMarketNoticeboardEntryBatch(self):
        """Test SecondaryMarketNoticeboardEntryBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import datetime

from pydantic import Field, StrictStr, conint, conlist

from typing import Optional

from empire_platform_api_public_client.models.audit_log_batch import AuditLogBatch
from empire_platform_api_public_client.models.audit_log_domain import AuditLogDomain
from empire_platform_api_public_client.models.audit_log_payload import AuditLogPayload
from empire_platform_api_public_client.models.audit_log_sort_by import AuditLogSortBy

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AuditLogApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_audit_log_payload(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> AuditLogPayload:  # noqa: E501
        """get_audit_log_payload  # noqa: E501

        Fetch payload for an existing Audit Log entry by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_log_payload(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuditLogPayload
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_audit_log_payload_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_audit_log_payload_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_audit_log_payload_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_audit_log_payload  # noqa: E501

        Fetch payload for an existing Audit Log entry by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_log_payload_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuditLogPayload, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_log_payload" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AuditLogPayload",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/audit-logs/{id}/payload', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_audit_logs(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : AuditLogSortBy, domains : Optional[conlist(AuditLogDomain)] = None, x_organisation_id : Annotated[Optional[StrictStr], Field(description="Internal ID of an Organisation (optional)")] = None, created_at_from : Optional[datetime] = None, created_at_to : Optional[datetime] = None, query : Optional[StrictStr] = None, **kwargs) -> AuditLogBatch:  # noqa: E501
        """get_audit_logs  # noqa: E501

        Fetch a list of Audit Logs optionally filtered for an Organisation  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_logs(limit, offset, sort_by, domains, x_organisation_id, created_at_from, created_at_to, query, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: (required)
        :type sort_by: AuditLogSortBy
        :param domains:
        :type domains: List[AuditLogDomain]
        :param x_organisation_id: Internal ID of an Organisation (optional)
        :type x_organisation_id: str
        :param created_at_from:
        :type created_at_from: datetime
        :param created_at_to:
        :type created_at_to: datetime
        :param query:
        :type query: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: AuditLogBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_audit_logs_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_audit_logs_with_http_info(limit, offset, sort_by, domains, x_organisation_id, created_at_from, created_at_to, query, **kwargs)  # noqa: E501

    @validate_arguments
    def get_audit_logs_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : AuditLogSortBy, domains : Optional[conlist(AuditLogDomain)] = None, x_organisation_id : Annotated[Optional[StrictStr], Field(description="Internal ID of an Organisation (optional)")] = None, created_at_from : Optional[datetime] = None, created_at_to : Optional[datetime] = None, query : Optional[StrictStr] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_audit_logs  # noqa: E501

        Fetch a list of Audit Logs optionally filtered for an Organisation  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_AUDIT_LOGS`   * `VIEW_ANY_AUDIT_LOGS`  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_audit_logs_with_http_info(limit, offset, sort_by, domains, x_organisation_id, created_at_from, created_at_to, query, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: (required)
        :type sort_by: AuditLogSortBy
        :param domains:
        :type domains: List[AuditLogDomain]
        :param x_organisation_id: Internal ID of an Organisation (optional)
        :type x_organisation_id: str
        :param created_at_from:
        :type created_at_from: datetime
        :param created_at_to:
        :type created_at_to: datetime
        :param query:
        :type query: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(AuditLogBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'sort_by',
            'domains',
            'x_organisation_id',
            'created_at_from',
            'created_at_to',
            'query'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_audit_logs" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('domains') is not None:  # noqa: E501
            _query_params.append(('domains', _params['domains']))
            _collection_formats['domains'] = 'multi'

        if _params.get('created_at_from') is not None:  # noqa: E501
            if isinstance(_params['created_at_from'], datetime):
                _query_params.append(('createdAtFrom', _params['created_at_from'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('createdAtFrom', _params['created_at_from']))

        if _params.get('created_at_to') is not None:  # noqa: E501
            if isinstance(_params['created_at_to'], datetime):
                _query_params.append(('createdAtTo', _params['created_at_to'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('createdAtTo', _params['created_at_to']))

        if _params.get('query') is not None:  # noqa: E501
            _query_params.append(('query', _params['query']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        if _params['x_organisation_id']:
            _header_params['X-Organisation-Id'] = _params['x_organisation_id']

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['ApiKey', 'AuthToken']  # noqa: E501

        _response_types_map = {
            '200': "AuditLogBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/audit-logs', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.audit_log_batch import AuditLogBatch  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestAuditLogBatch(unittest.TestCase):
    """AuditLogBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AuditLogBatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuditLogBatch`
        """
        model = empire_platform_api_public_client.models.audit_log_batch.AuditLogBatch()  # noqa: E501
        if include_optional :
            return AuditLogBatch(
                entries = [
                    empire_platform_api_public_client.models.audit_log.AuditLog(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        created_at = '2022-01-04T00:00Z', 
                        user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                                name = '', ), ), 
                        domain = 'AUCTIONS', 
                        type = 'CREATE_LONG_TERM_AUCTION', 
                        status = 'SUCCESS', 
                        description = '', 
                        impersonated_by_user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = , 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = , 
                                name = '', ), ), 
                        requested_with_api_key = empire_platform_api_public_client.models.audit_log_api_key.AuditLogApiKey(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            created_at = '2022-01-04T00:00Z', ), )
                    ], 
                total_count = 0
            )
        else :
            return AuditLogBatch(
                entries = [
                    empire_platform_api_public_client.models.audit_log.AuditLog(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        created_at = '2022-01-04T00:00Z', 
                        user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                                name = '', ), ), 
                        domain = 'AUCTIONS', 
                        type = 'CREATE_LONG_TERM_AUCTION', 
                        status = 'SUCCESS', 
                        description = '', 
                        impersonated_by_user = empire_platform_api_public_client.models.audit_log_user.AuditLogUser(
                            id = , 
                            name = '', 
                            role = 'ICO_ADMIN_BDL', 
                            organisation = empire_platform_api_public_client.models.audit_log_user_organisation.AuditLogUserOrganisation(
                                id = , 
                                name = '', ), ), 
                        requested_with_api_key = empire_platform_api_public_client.models.audit_log_api_key.AuditLogApiKey(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', 
                            created_at = '2022-01-04T00:00Z', ), )
                    ],
                total_count = 0,
        )
        """

    def testAuditLogBatch(self):
        """Test AuditLogBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import empire_platform_api_public_client
from empire_platform_api_public_client.api.public_auction_api import PublicAuctionApi  # noqa: E501
from empire_platform_api_public_client.rest import ApiException


class TestPublicAuctionApi(unittest.TestCase):
    """PublicAuctionApi unit test stubs"""

    def setUp(self):
        self.api = empire_platform_api_public_client.api.public_auction_api.PublicAuctionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_public_auction_reduction_periods(self):
        """Test case for get_public_auction_reduction_periods

        """
        pass

    def test_get_public_auctions(self):
        """Test case for get_public_auctions

        """
        pass

    def test_get_public_day_ahead_auction(self):
        """Test case for get_public_day_ahead_auction

        """
        pass

    def test_get_public_day_ahead_or_intra_day_auction_mtu_results(self):
        """Test case for get_public_day_ahead_or_intra_day_auction_mtu_results

        """
        pass

    def test_get_public_day_ahead_or_intra_day_auction_results(self):
        """Test case for get_public_day_ahead_or_intra_day_auction_results

        """
        pass

    def test_get_public_intra_day_auction(self):
        """Test case for get_public_intra_day_auction

        """
        pass

    def test_get_public_long_term_auction(self):
        """Test case for get_public_long_term_auction

        """
        pass

    def test_get_public_long_term_auction_calendar(self):
        """Test case for get_public_long_term_auction_calendar

        """
        pass

    def test_get_public_long_term_auction_results(self):
        """Test case for get_public_long_term_auction_results

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.message_batch import MessageBatch  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestMessageBatch(unittest.TestCase):
    """MessageBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MessageBatch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MessageBatch`
        """
        model = empire_platform_api_public_client.models.message_batch.MessageBatch()  # noqa: E501
        if include_optional :
            return MessageBatch(
                entries = [
                    empire_platform_api_public_client.models.message.Message(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        received_at = '2022-01-04T00:00Z', 
                        category = 'GENERAL', 
                        sender = 'ICO', 
                        severity = 'CRITICAL_ALERT', 
                        type = 'AUCTION', 
                        subject = '', 
                        body = '', 
                        read = True, 
                        entity_id = '', 
                        attachment = empire_platform_api_public_client.models.attachment.Attachment(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            file_name = '', 
                            file_size = 0, 
                            mime_type = '', 
                            url = '', ), )
                    ], 
                total_count = 0
            )
        else :
            return MessageBatch(
                entries = [
                    empire_platform_api_public_client.models.message.Message(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        received_at = '2022-01-04T00:00Z', 
                        category = 'GENERAL', 
                        sender = 'ICO', 
                        severity = 'CRITICAL_ALERT', 
                        type = 'AUCTION', 
                        subject = '', 
                        body = '', 
                        read = True, 
                        entity_id = '', 
                        attachment = empire_platform_api_public_client.models.attachment.Attachment(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            file_name = '', 
                            file_size = 0, 
                            mime_type = '', 
                            url = '', ), )
                    ],
                total_count = 0,
        )
        """

    def testMessageBatch(self):
        """Test MessageBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request import CreateDayAheadOrIntraDayDefaultBidRequest  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestCreateDayAheadOrIntraDayDefaultBidRequest(unittest.TestCase):
    """CreateDayAheadOrIntraDayDefaultBidRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateDayAheadOrIntraDayDefaultBidRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateDayAheadOrIntraDayDefaultBidRequest`
        """
        model = empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request.CreateDayAheadOrIntraDayDefaultBidRequest()  # noqa: E501
        if include_optional :
            return CreateDayAheadOrIntraDayDefaultBidRequest(
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL', 
                border_direction = 'GB_NL', 
                delivery_period_start = '2022-01-04T10:00Z', 
                delivery_period_end = '2022-01-04T11:00Z', 
                validity_period_start = '2022-01-04T00:00Z', 
                validity_period_end = '2022-01-04T00:00Z', 
                mtu_size = 'MTU_15_MINS', 
                bids = [
                    empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner(
                        mtus = [
                            empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner_mtus_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner_mtus_inner(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ]
            )
        else :
            return CreateDayAheadOrIntraDayDefaultBidRequest(
                auction_product_type = 'LT_EXPLICIT_MULTI_ANNUAL',
                border_direction = 'GB_NL',
                delivery_period_start = '2022-01-04T10:00Z',
                validity_period_start = '2022-01-04T00:00Z',
                mtu_size = 'MTU_15_MINS',
                bids = [
                    empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner(
                        mtus = [
                            empire_platform_api_public_client.models.create_day_ahead_or_intra_day_default_bid_request_bids_inner_mtus_inner.CreateDayAheadOrIntraDayDefaultBidRequest_bids_inner_mtus_inner(
                                mtu = '10:00', 
                                value = empire_platform_api_public_client.models.bid_value.BidValue(
                                    price = 1.337, 
                                    capacity = 56, ), )
                            ], )
                    ],
        )
        """

    def testCreateDayAheadOrIntraDayDefaultBidRequest(self):
        """Test CreateDayAheadOrIntraDayDefaultBidRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.participant_dashboard_transmission_rights_and_nominations_data_mtus_inner_values_inner_nomination_restriction import ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInnerNominationRestriction

class ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner(BaseModel):
    """
    ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner
    """
    direction: BorderDirection = Field(...)
    allocated_trs: StrictInt = Field(..., alias="allocatedTrs", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    nominated_capacity: StrictInt = Field(..., alias="nominatedCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    nomination_restriction: Optional[ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInnerNominationRestriction] = Field(None, alias="nominationRestriction")
    __properties = ["direction", "allocatedTrs", "nominatedCapacity", "nominationRestriction"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner:
        """Create an instance of ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of nomination_restriction
        if self.nomination_restriction:
            _dict['nominationRestriction'] = self.nomination_restriction.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner:
        """Create an instance of ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner.parse_obj(obj)

        _obj = ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInner.parse_obj({
            "direction": obj.get("direction"),
            "allocated_trs": obj.get("allocatedTrs"),
            "nominated_capacity": obj.get("nominatedCapacity"),
            "nomination_restriction": ParticipantDashboardTransmissionRightsAndNominationsDataMtusInnerValuesInnerNominationRestriction.from_dict(obj.get("nominationRestriction")) if obj.get("nominationRestriction") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.default_nomination_options import DefaultNominationOptions  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestDefaultNominationOptions(unittest.TestCase):
    """DefaultNominationOptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DefaultNominationOptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DefaultNominationOptions`
        """
        model = empire_platform_api_public_client.models.default_nomination_options.DefaultNominationOptions()  # noqa: E501
        if include_optional :
            return DefaultNominationOptions(
                mtu_sizes = [
                    empire_platform_api_public_client.models.mtu_size_per_timescale.MtuSizePerTimescale(
                        timescale = 'LONG_TERM', 
                        mtu_size = 'MTU_15_MINS', )
                    ]
            )
        else :
            return DefaultNominationOptions(
                mtu_sizes = [
                    empire_platform_api_public_client.models.mtu_size_per_timescale.MtuSizePerTimescale(
                        timescale = 'LONG_TERM', 
                        mtu_size = 'MTU_15_MINS', )
                    ],
        )
        """

    def testDefaultNominationOptions(self):
        """Test DefaultNominationOptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class DefaultBidSortBy(str, Enum):
    """
    DefaultBidSortBy
    """

    """
    allowed enum values
    """
    AUCTION_PRODUCT_TYPE_ASC = 'AUCTION_PRODUCT_TYPE_ASC'
    AUCTION_PRODUCT_TYPE_DESC = 'AUCTION_PRODUCT_TYPE_DESC'
    DELIVERY_PERIOD_START_ASC = 'DELIVERY_PERIOD_START_ASC'
    DELIVERY_PERIOD_START_DESC = 'DELIVERY_PERIOD_START_DESC'
    DELIVERY_PERIOD_END_ASC = 'DELIVERY_PERIOD_END_ASC'
    DELIVERY_PERIOD_END_DESC = 'DELIVERY_PERIOD_END_DESC'
    VALIDITY_PERIOD_START_ASC = 'VALIDITY_PERIOD_START_ASC'
    VALIDITY_PERIOD_START_DESC = 'VALIDITY_PERIOD_START_DESC'
    VALIDITY_PERIOD_END_ASC = 'VALIDITY_PERIOD_END_ASC'
    VALIDITY_PERIOD_END_DESC = 'VALIDITY_PERIOD_END_DESC'
    BORDER_DIRECTION_ASC = 'BORDER_DIRECTION_ASC'
    BORDER_DIRECTION_DESC = 'BORDER_DIRECTION_DESC'

    @classmethod
    def from_json(cls, json_str: str) -> DefaultBidSortBy:
        """Create an instance of DefaultBidSortBy from a JSON string"""
        return DefaultBidSortBy(json.loads(json_str))





# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, conlist
from empire_platform_api_public_client.models.mtu_size import MtuSize
from empire_platform_api_public_client.models.uiosi_overview_per_mtu import UiosiOverviewPerMtu

class UiosiOverview(BaseModel):
    """
    UiosiOverview
    """
    mtu_size: MtuSize = Field(..., alias="mtuSize")
    mtus: conlist(UiosiOverviewPerMtu) = Field(...)
    __properties = ["mtuSize", "mtus"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UiosiOverview:
        """Create an instance of UiosiOverview from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in mtus (list)
        _items = []
        if self.mtus:
            for _item in self.mtus:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mtus'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UiosiOverview:
        """Create an instance of UiosiOverview from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UiosiOverview.parse_obj(obj)

        _obj = UiosiOverview.parse_obj({
            "mtu_size": obj.get("mtuSize"),
            "mtus": [UiosiOverviewPerMtu.from_dict(_item) for _item in obj.get("mtus")] if obj.get("mtus") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conint
from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.auction_status import AuctionStatus
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.date_time_period import DateTimePeriod
from empire_platform_api_public_client.models.mtu_period import MtuPeriod

class Auction(BaseModel):
    """
    * `offeredCapacity` = Offered capacity in kilowatts. Optional, only set for LT auctions, and should be calculated as MAX(OC) over the MTUs in the delivery period. * `currentParticipantBidCount` - Number of bids made by the organisation of the currently logged in user. Optional, only sent when the currently logged in user belongs to a PARTICIPANT type organisation. 
    """
    id: StrictStr = Field(..., description="Unique identifier for the record in UUID4 format")
    display_id: StrictStr = Field(..., alias="displayId", description="Generated display identifier")
    product_type: AuctionProductType = Field(..., alias="productType")
    border_direction: BorderDirection = Field(..., alias="borderDirection")
    status: AuctionStatus = Field(...)
    processing: StrictBool = Field(...)
    delivery_period: MtuPeriod = Field(..., alias="deliveryPeriod")
    bidding_period: DateTimePeriod = Field(..., alias="biddingPeriod")
    name: StrictStr = Field(..., description="Human readable name")
    pre_bidding_allowed: StrictBool = Field(..., alias="preBiddingAllowed")
    offered_capacity: Optional[StrictInt] = Field(None, alias="offeredCapacity", description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers")
    current_participant_bid_count: Optional[conint(strict=True, ge=0)] = Field(None, alias="currentParticipantBidCount", description="Natural numbers {0, 1, 2, 3, ...} used for counting elements")
    returns_window_close: Optional[datetime] = Field(None, alias="returnsWindowClose", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["id", "displayId", "productType", "borderDirection", "status", "processing", "deliveryPeriod", "biddingPeriod", "name", "preBiddingAllowed", "offeredCapacity", "currentParticipantBidCount", "returnsWindowClose"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Auction:
        """Create an instance of Auction from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of delivery_period
        if self.delivery_period:
            _dict['deliveryPeriod'] = self.delivery_period.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bidding_period
        if self.bidding_period:
            _dict['biddingPeriod'] = self.bidding_period.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Auction:
        """Create an instance of Auction from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Auction.parse_obj(obj)

        _obj = Auction.parse_obj({
            "id": obj.get("id"),
            "display_id": obj.get("displayId"),
            "product_type": obj.get("productType"),
            "border_direction": obj.get("borderDirection"),
            "status": obj.get("status"),
            "processing": obj.get("processing"),
            "delivery_period": MtuPeriod.from_dict(obj.get("deliveryPeriod")) if obj.get("deliveryPeriod") is not None else None,
            "bidding_period": DateTimePeriod.from_dict(obj.get("biddingPeriod")) if obj.get("biddingPeriod") is not None else None,
            "name": obj.get("name"),
            "pre_bidding_allowed": obj.get("preBiddingAllowed"),
            "offered_capacity": obj.get("offeredCapacity"),
            "current_participant_bid_count": obj.get("currentParticipantBidCount"),
            "returns_window_close": obj.get("returnsWindowClose")
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import empire_platform_api_public_client
from empire_platform_api_public_client.models.user_preferences_general_notifications import UserPreferencesGeneralNotifications  # noqa: E501
from empire_platform_api_public_client.rest import ApiException

class TestUserPreferencesGeneralNotifications(unittest.TestCase):
    """UserPreferencesGeneralNotifications unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserPreferencesGeneralNotifications
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserPreferencesGeneralNotifications`
        """
        model = empire_platform_api_public_client.models.user_preferences_general_notifications.UserPreferencesGeneralNotifications()  # noqa: E501
        if include_optional :
            return UserPreferencesGeneralNotifications(
                critical_alert = empire_platform_api_public_client.models.notification_preference_with_sms.NotificationPreferenceWithSms(
                    email = True, 
                    sms = True, ), 
                critical = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ), 
                major = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ), 
                normal = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, )
            )
        else :
            return UserPreferencesGeneralNotifications(
                critical_alert = empire_platform_api_public_client.models.notification_preference_with_sms.NotificationPreferenceWithSms(
                    email = True, 
                    sms = True, ),
                critical = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ),
                major = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ),
                normal = empire_platform_api_public_client.models.notification_preference.NotificationPreference(
                    email = True, ),
        )
        """

    def testUserPreferencesGeneralNotifications(self):
        """Test UserPreferencesGeneralNotifications"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist, constr, validator
from empire_platform_api_public_client.models.secondary_market_day_ahead_or_intra_day_noticeboard_entry_response_mtus_inner import SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponseMtusInner

class SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse(BaseModel):
    """
    SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse
    """
    mtus: conlist(SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponseMtusInner) = Field(...)
    contact_name: StrictStr = Field(..., alias="contactName")
    phone_number: constr(strict=True) = Field(..., alias="phoneNumber")
    email: constr(strict=True) = Field(...)
    comment: Optional[StrictStr] = None
    responded_at: datetime = Field(..., alias="respondedAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["mtus", "contactName", "phoneNumber", "email", "comment", "respondedAt"]

    # @validator('phone_number')
    def phone_number_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^\+\d{10,13}$", value):
            raise ValueError(r"must validate the regular expression /^\+\d{10,13}$/")
        return value

    # @validator('email')
    def email_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[\w-\.]+@([\w-]+\.)+[\w-]{2,6}$", value):
            raise ValueError(r"must validate the regular expression /^[\w-\.]+@([\w-]+\.)+[\w-]{2,6}$/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse:
        """Create an instance of SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in mtus (list)
        _items = []
        if self.mtus:
            for _item in self.mtus:
                if _item:
                    _items.append(_item.to_dict())
            _dict['mtus'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse:
        """Create an instance of SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse.parse_obj(obj)

        _obj = SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponse.parse_obj({
            "mtus": [SecondaryMarketDayAheadOrIntraDayNoticeboardEntryResponseMtusInner.from_dict(_item) for _item in obj.get("mtus")] if obj.get("mtus") is not None else None,
            "contact_name": obj.get("contactName"),
            "phone_number": obj.get("phoneNumber"),
            "email": obj.get("email"),
            "comment": obj.get("comment"),
            "responded_at": obj.get("respondedAt")
        })
        return _obj




# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from datetime import datetime

from pydantic import Field, StrictStr, conint

from typing import List, Optional

from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.auction_reduction_period import AuctionReductionPeriod
from empire_platform_api_public_client.models.auction_sort_by import AuctionSortBy
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.public_auction_batch import PublicAuctionBatch
from empire_platform_api_public_client.models.public_auction_status import PublicAuctionStatus
from empire_platform_api_public_client.models.public_day_ahead_auction import PublicDayAheadAuction
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_mtu_results import PublicDayAheadOrIntraDayAuctionMtuResults
from empire_platform_api_public_client.models.public_day_ahead_or_intra_day_auction_results import PublicDayAheadOrIntraDayAuctionResults
from empire_platform_api_public_client.models.public_intra_day_auction import PublicIntraDayAuction
from empire_platform_api_public_client.models.public_long_term_auction import PublicLongTermAuction
from empire_platform_api_public_client.models.public_long_term_auction_results import PublicLongTermAuctionResults

from empire_platform_api_public_client.api_client import ApiClient
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PublicAuctionApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_public_auction_reduction_periods(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> List[AuctionReductionPeriod]:  # noqa: E501
        """get_public_auction_reduction_periods  # noqa: E501

        Fetch reduction periods that possibly affects the Auction  See more at `getAuctionReductionPeriods`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_auction_reduction_periods(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[AuctionReductionPeriod]
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_auction_reduction_periods_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_auction_reduction_periods_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_auction_reduction_periods_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_auction_reduction_periods  # noqa: E501

        Fetch reduction periods that possibly affects the Auction  See more at `getAuctionReductionPeriods`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_auction_reduction_periods_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[AuctionReductionPeriod], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_auction_reduction_periods" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "List[AuctionReductionPeriod]",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/{id}/reduction-periods', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_auctions(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[AuctionSortBy, Field(..., description="Sort list by given attribute and direction")], border_direction : Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None, timescale : Annotated[Optional[AuctionTimescale], Field(description="Auction Timescale (optional)")] = None, product_type : Annotated[Optional[AuctionProductType], Field(description="Auction Product Type (optional)")] = None, status : Annotated[Optional[PublicAuctionStatus], Field(description="Filter for given (published) status")] = None, bidding_period_start : Annotated[Optional[datetime], Field(description="Filter for start of bidding period")] = None, bidding_period_end : Annotated[Optional[datetime], Field(description="Filter for end of bidding period")] = None, delivery_period_start : Annotated[Optional[datetime], Field(description="Filter for start of delivery period (aligned to MTUs)")] = None, delivery_period_end : Annotated[Optional[datetime], Field(description="Filter for end of delivery period (aligned to MTUs)")] = None, query : Annotated[Optional[StrictStr], Field(description="Free text search in name")] = None, **kwargs) -> PublicAuctionBatch:  # noqa: E501
        """get_public_auctions  # noqa: E501

        Fetch a paginated, sortable, filterable list of Auctions  See more at `getAuctions`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_auctions(limit, offset, sort_by, border_direction, timescale, product_type, status, bidding_period_start, bidding_period_end, delivery_period_start, delivery_period_end, query, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: AuctionSortBy
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescale: Auction Timescale (optional)
        :type timescale: AuctionTimescale
        :param product_type: Auction Product Type (optional)
        :type product_type: AuctionProductType
        :param status: Filter for given (published) status
        :type status: PublicAuctionStatus
        :param bidding_period_start: Filter for start of bidding period
        :type bidding_period_start: datetime
        :param bidding_period_end: Filter for end of bidding period
        :type bidding_period_end: datetime
        :param delivery_period_start: Filter for start of delivery period (aligned to MTUs)
        :type delivery_period_start: datetime
        :param delivery_period_end: Filter for end of delivery period (aligned to MTUs)
        :type delivery_period_end: datetime
        :param query: Free text search in name
        :type query: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicAuctionBatch
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_auctions_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_auctions_with_http_info(limit, offset, sort_by, border_direction, timescale, product_type, status, bidding_period_start, bidding_period_end, delivery_period_start, delivery_period_end, query, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_auctions_with_http_info(self, limit : Annotated[conint(strict=True, le=100, ge=1), Field(..., description="Number of records to return on a page")], offset : Annotated[conint(strict=True, ge=0), Field(..., description="Offset in the list of records to return")], sort_by : Annotated[AuctionSortBy, Field(..., description="Sort list by given attribute and direction")], border_direction : Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None, timescale : Annotated[Optional[AuctionTimescale], Field(description="Auction Timescale (optional)")] = None, product_type : Annotated[Optional[AuctionProductType], Field(description="Auction Product Type (optional)")] = None, status : Annotated[Optional[PublicAuctionStatus], Field(description="Filter for given (published) status")] = None, bidding_period_start : Annotated[Optional[datetime], Field(description="Filter for start of bidding period")] = None, bidding_period_end : Annotated[Optional[datetime], Field(description="Filter for end of bidding period")] = None, delivery_period_start : Annotated[Optional[datetime], Field(description="Filter for start of delivery period (aligned to MTUs)")] = None, delivery_period_end : Annotated[Optional[datetime], Field(description="Filter for end of delivery period (aligned to MTUs)")] = None, query : Annotated[Optional[StrictStr], Field(description="Free text search in name")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_auctions  # noqa: E501

        Fetch a paginated, sortable, filterable list of Auctions  See more at `getAuctions`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_auctions_with_http_info(limit, offset, sort_by, border_direction, timescale, product_type, status, bidding_period_start, bidding_period_end, delivery_period_start, delivery_period_end, query, async_req=True)
        >>> result = thread.get()

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param sort_by: Sort list by given attribute and direction (required)
        :type sort_by: AuctionSortBy
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescale: Auction Timescale (optional)
        :type timescale: AuctionTimescale
        :param product_type: Auction Product Type (optional)
        :type product_type: AuctionProductType
        :param status: Filter for given (published) status
        :type status: PublicAuctionStatus
        :param bidding_period_start: Filter for start of bidding period
        :type bidding_period_start: datetime
        :param bidding_period_end: Filter for end of bidding period
        :type bidding_period_end: datetime
        :param delivery_period_start: Filter for start of delivery period (aligned to MTUs)
        :type delivery_period_start: datetime
        :param delivery_period_end: Filter for end of delivery period (aligned to MTUs)
        :type delivery_period_end: datetime
        :param query: Free text search in name
        :type query: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicAuctionBatch, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'limit',
            'offset',
            'sort_by',
            'border_direction',
            'timescale',
            'product_type',
            'status',
            'bidding_period_start',
            'bidding_period_end',
            'delivery_period_start',
            'delivery_period_end',
            'query'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_auctions" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('limit') is not None:  # noqa: E501
            _query_params.append(('limit', _params['limit']))

        if _params.get('offset') is not None:  # noqa: E501
            _query_params.append(('offset', _params['offset']))

        if _params.get('sort_by') is not None:  # noqa: E501
            _query_params.append(('sortBy', _params['sort_by'].value))

        if _params.get('border_direction') is not None:  # noqa: E501
            _query_params.append(('borderDirection', _params['border_direction'].value))

        if _params.get('timescale') is not None:  # noqa: E501
            _query_params.append(('timescale', _params['timescale'].value))

        if _params.get('product_type') is not None:  # noqa: E501
            _query_params.append(('productType', _params['product_type'].value))

        if _params.get('status') is not None:  # noqa: E501
            _query_params.append(('status', _params['status'].value))

        if _params.get('bidding_period_start') is not None:  # noqa: E501
            if isinstance(_params['bidding_period_start'], datetime):
                _query_params.append(('biddingPeriodStart', _params['bidding_period_start'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('biddingPeriodStart', _params['bidding_period_start']))

        if _params.get('bidding_period_end') is not None:  # noqa: E501
            if isinstance(_params['bidding_period_end'], datetime):
                _query_params.append(('biddingPeriodEnd', _params['bidding_period_end'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('biddingPeriodEnd', _params['bidding_period_end']))

        if _params.get('delivery_period_start') is not None:  # noqa: E501
            if isinstance(_params['delivery_period_start'], datetime):
                _query_params.append(('deliveryPeriodStart', _params['delivery_period_start'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('deliveryPeriodStart', _params['delivery_period_start']))

        if _params.get('delivery_period_end') is not None:  # noqa: E501
            if isinstance(_params['delivery_period_end'], datetime):
                _query_params.append(('deliveryPeriodEnd', _params['delivery_period_end'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('deliveryPeriodEnd', _params['delivery_period_end']))

        if _params.get('query') is not None:  # noqa: E501
            _query_params.append(('query', _params['query']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicAuctionBatch",
            '422': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_day_ahead_auction(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> PublicDayAheadAuction:  # noqa: E501
        """get_public_day_ahead_auction  # noqa: E501

        Fetch a Day Ahead Auction by its identifier  See more at `getDayAheadAuction`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_day_ahead_auction(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicDayAheadAuction
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_day_ahead_auction_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_day_ahead_auction_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_day_ahead_auction_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_day_ahead_auction  # noqa: E501

        Fetch a Day Ahead Auction by its identifier  See more at `getDayAheadAuction`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_day_ahead_auction_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicDayAheadAuction, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_day_ahead_auction" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicDayAheadAuction",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/day-ahead/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_day_ahead_or_intra_day_auction_mtu_results(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], mtu : datetime, **kwargs) -> PublicDayAheadOrIntraDayAuctionMtuResults:  # noqa: E501
        """get_public_day_ahead_or_intra_day_auction_mtu_results  # noqa: E501

        Fetch results for a given MTU in a Day Ahead or an Intra-Day Auction by its identifier  See more at `getDayAheadOrIntraDayAuctionMtuResults`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_day_ahead_or_intra_day_auction_mtu_results(id, mtu, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param mtu: (required)
        :type mtu: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicDayAheadOrIntraDayAuctionMtuResults
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_day_ahead_or_intra_day_auction_mtu_results_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_day_ahead_or_intra_day_auction_mtu_results_with_http_info(id, mtu, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_day_ahead_or_intra_day_auction_mtu_results_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], mtu : datetime, **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_day_ahead_or_intra_day_auction_mtu_results  # noqa: E501

        Fetch results for a given MTU in a Day Ahead or an Intra-Day Auction by its identifier  See more at `getDayAheadOrIntraDayAuctionMtuResults`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_day_ahead_or_intra_day_auction_mtu_results_with_http_info(id, mtu, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param mtu: (required)
        :type mtu: datetime
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicDayAheadOrIntraDayAuctionMtuResults, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id',
            'mtu'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_day_ahead_or_intra_day_auction_mtu_results" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        if _params.get('mtu') is not None:  # noqa: E501
            if isinstance(_params['mtu'], datetime):
                _query_params.append(('mtu', _params['mtu'].strftime(self.api_client.configuration.datetime_format)))
            else:
                _query_params.append(('mtu', _params['mtu']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicDayAheadOrIntraDayAuctionMtuResults",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '409': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/day-ahead-or-intra-day/{id}/results/mtus', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_day_ahead_or_intra_day_auction_results(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> PublicDayAheadOrIntraDayAuctionResults:  # noqa: E501
        """get_public_day_ahead_or_intra_day_auction_results  # noqa: E501

        Fetch results for a Day Ahead or an Intra Day Auction by its identifier  See more at `getDayAheadOrIntraDayAuctionResults`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_day_ahead_or_intra_day_auction_results(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicDayAheadOrIntraDayAuctionResults
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_day_ahead_or_intra_day_auction_results_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_day_ahead_or_intra_day_auction_results_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_day_ahead_or_intra_day_auction_results_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_day_ahead_or_intra_day_auction_results  # noqa: E501

        Fetch results for a Day Ahead or an Intra Day Auction by its identifier  See more at `getDayAheadOrIntraDayAuctionResults`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_day_ahead_or_intra_day_auction_results_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicDayAheadOrIntraDayAuctionResults, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_day_ahead_or_intra_day_auction_results" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicDayAheadOrIntraDayAuctionResults",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '409': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/day-ahead-or-intra-day/{id}/results', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_intra_day_auction(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> PublicIntraDayAuction:  # noqa: E501
        """get_public_intra_day_auction  # noqa: E501

        Fetch an Intra Day Auction by its identifier  See more at `getIntraDayAuction`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_intra_day_auction(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicIntraDayAuction
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_intra_day_auction_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_intra_day_auction_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_intra_day_auction_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_intra_day_auction  # noqa: E501

        Fetch an Intra Day Auction by its identifier  See more at `getIntraDayAuction`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_intra_day_auction_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicIntraDayAuction, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_intra_day_auction" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicIntraDayAuction",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/intra-day/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_long_term_auction(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> PublicLongTermAuction:  # noqa: E501
        """get_public_long_term_auction  # noqa: E501

        Fetch a Long Term Auction by its identifier  See more at `getLongTermAuction`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_long_term_auction(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicLongTermAuction
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_long_term_auction_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_long_term_auction_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_long_term_auction_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_long_term_auction  # noqa: E501

        Fetch a Long Term Auction by its identifier  See more at `getLongTermAuction`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_long_term_auction_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicLongTermAuction, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_long_term_auction" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicLongTermAuction",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/long-term/{id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_long_term_auction_calendar(self, **kwargs) -> str:  # noqa: E501
        """get_public_long_term_auction_calendar  # noqa: E501

        Fetch Long Term Auction \"bidding windows\" in iCal format, suitable for calendar subscriptions   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_long_term_auction_calendar(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_long_term_auction_calendar_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_long_term_auction_calendar_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_public_long_term_auction_calendar_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_long_term_auction_calendar  # noqa: E501

        Fetch Long Term Auction \"bidding windows\" in iCal format, suitable for calendar subscriptions   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_long_term_auction_calendar_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_long_term_auction_calendar" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/calendar'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "str",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/long-term/calendar', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_public_long_term_auction_results(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> PublicLongTermAuctionResults:  # noqa: E501
        """get_public_long_term_auction_results  # noqa: E501

        Fetch results for a Long Term Auction by its identifier  See more at `getLongTermAuctionResults`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_long_term_auction_results(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicLongTermAuctionResults
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            raise ValueError("Error! Please call the get_public_long_term_auction_results_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data")
        return self.get_public_long_term_auction_results_with_http_info(id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_public_long_term_auction_results_with_http_info(self, id : Annotated[StrictStr, Field(..., description="Internal unique ID of an entity")], **kwargs) -> ApiResponse:  # noqa: E501
        """get_public_long_term_auction_results  # noqa: E501

        Fetch results for a Long Term Auction by its identifier  See more at `getLongTermAuctionResults`   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_public_long_term_auction_results_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the 
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicLongTermAuctionResults, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_public_long_term_auction_results" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['id']:
            _path_params['id'] = _params['id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "PublicLongTermAuctionResults",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '409': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/v1/public/auctions/long-term/{id}/results', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Empire - Platform API

    OpenAPI specification for the Platform REST API of Empire  **System Time:** Europe/Amsterdam  **General data formats:**   * _capacity values_ => kW (integers)   * _dates and local times_ => System Time   * _currencies_ => EUR   # noqa: E501

    The version of the OpenAPI document: 0.178.3
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class PublicAuctionBidStatus(str, Enum):
    """
    PublicAuctionBidStatus
    """

    """
    allowed enum values
    """
    SUCCESSFUL = 'SUCCESSFUL'
    PARTIALLY_SUCCESSFUL = 'PARTIALLY_SUCCESSFUL'
    UNSUCCESSFUL = 'UNSUCCESSFUL'

    @classmethod
    def from_json(cls, json_str: str) -> PublicAuctionBidStatus:
        """Create an instance of PublicAuctionBidStatus from a JSON string"""
        return PublicAuctionBidStatus(json.loads(json_str))


